@@ -26,6 +26,8 @@ OAUTH2_CLIENT_SECRET='EIMML1W7anu0XijVghws0DY-'
 
 
 GCE_PROJECT_ID='bigjob-pilot'
+USER_ID='luckow'
+SSH_KEY_FILE='/Users/luckow/.ssh/google_compute_engine'
 
 class gce_states:
     PROVISIONING="PROVISIONING"
@@ -89,9 +91,32 @@ class gcessh:
         compute_instance_details = self.__get_instance_resource()
         logger.debug("Compute Instance Details: " + str(compute_instance_details))
         self.network_ip = compute_instance_details["networkInterfaces"][0]["accessConfigs"][0]['natIP']
+        url = "ssh://" + self.network_ip
+        logger.debug("Connect to: %s"%(url))
+        js = saga.job.Service(saga.Url(url))
         
-        js = saga.job.Service(os.path.join("ssh://". self.network_ip))
+        jd = saga.job.Description()
+        jd.arguments = [""]
+        jd.executable = "/bin/date"
+        jd.working_directory =  "/tmp"
+        jd.output = "bliss_ssh_job.stdout"
+        jd.error  = "bliss_ssh_job.stderr"
         
+        # Submit job
+        ctx = saga.Context()
+        ctx.type = saga.Context.SSH
+        ctx.userid  = USER_ID
+        ctx.userkey = SSH_KEY_FILE
+        js.session.contexts.append(ctx)
+
+        job = js.create_job(jd)
+        print "Submit pilot job to: " + str(url)
+        job.run()
+        job.wait()
+        
+        print "Job State : %s" % (job.get_state())
+        print "Exitcode  : %s" % (job.exitcode)
+
 
     def wait(self):
         while self.get_state()!=gce_states.RUNNING:
